==> nextcloud-19.0.3.tgz: nextcloud/apps/password_policy/l10n/sk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Platnosť hesla skončila - nastavte si prosím nové heslo pomocou metódy pre zabudnuté heslo",
    "Password must not have been used recently before." : "Heslo nesmie byť z tých, ktoré boli nastavené nedávno.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné.",
    "Password is present in compromised password list. Please choose a different password." : "Heslo sa našlo v zozname uniknutých hesiel. Prosím, zvolte si iné heslo.",
    "Password needs to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Password needs to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovať aspoň jedno malé a jedno veľké písmeno.",
    "Password policy" : "Politika hesla",
    "Allows admins to configure a password policy" : "Povoliť adminom nastaviť politiku hesiel",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Povoliť adminom definovať pravidlá pre tvorbu hesiel. Napríklad minimálny počet znakov.",
    "Minimal length" : "Minimálna dĺžka",
    "User password history" : "História hesiel používateľa",
    "days until user password expires" : "dní do skončenia platnosti hesla používateľa",
    "login attempts before the user account is blocked. (0 for no limit)" : "pokusy o prihlásenie pred zablokovaním používateľského účtu. (0 bez obmedzenia)",
    "Forbid common passwords" : "Zakázať najpoužívanejšie heslá",
    "Enforce upper and lower case characters" : "Vynútiť veľké a malé znaky",
    "Enforce numeric characters" : "Vynútiť numerické znaky",
    "Enforce special characters" : "Vynútiť špeciálne znaky",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrolovať heslo v zozname uniknutých hesiel z haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Toto vytvorí kontrolný súčet z hesla a pošle prvých 5 znakov kontrolného súčtu do haveibeenpwned.com API. Prijme sa zoznam všetkých kontrolných súčtov, ktoré začínajú na tých 5 znakov. Potom sa kontroluje, či sa zadané heslo nachádza v prijatom zozname."
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-21.0.3.tgz: nextcloud/apps/password_policy/l10n/sk.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Platnosť hesla skončila - nastavte si prosím nové heslo pomocou metódy pre zabudnuté heslo",
    "Password must not have been used recently before." : "Heslo nesmie byť z tých, ktoré boli nastavené nedávno.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Heslo je v zozname 1 000 000 najpoužívanejších hesiel. Vyberte prosím iné.",
    "Password is present in compromised password list. Please choose a different password." : "Heslo sa našlo v zozname uniknutých hesiel. Prosím, zvolte si iné heslo.",
    "Password needs to contain at least one numeric character." : "Heslo musí obsahovať aspoň jeden numerický znak.",
    "Password needs to contain at least one special character." : "Heslo musí obsahovať aspoň jeden špeciálny znak.",
    "Password needs to contain at least one lower and one upper case character." : "Heslo musí obsahovať aspoň jedno malé a jedno veľké písmeno.",
    "Password policy" : "Politika hesla",
    "Allows admins to configure a password policy" : "Povoliť adminom nastaviť politiku hesiel",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Povoliť adminom definovať pravidlá pre tvorbu hesiel. Napríklad minimálny počet znakov.",
    "Minimum password length" : "Minimálna dĺžka hesla",
    "User password history" : "História hesiel používateľa",
    "Number of days until user password expires" : "Počet dní do vypršania platnosti hesla používateľa",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Počet pokusov o prihlásenie pred zablokovaním používateľského účtu (0 bez obmedzenia)",
    "Forbid common passwords" : "Zakázať najpoužívanejšie heslá",
    "Enforce upper and lower case characters" : "Vynútiť veľké a malé znaky",
    "Enforce numeric characters" : "Vynútiť numerické znaky",
    "Enforce special characters" : "Vynútiť špeciálne znaky",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrolovať heslo v zozname uniknutých hesiel z haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Toto vytvorí kontrolný súčet z hesla a pošle prvých 5 znakov kontrolného súčtu do haveibeenpwned.com API. Prijme sa zoznam všetkých kontrolných súčtov, ktoré začínajú na tých 5 znakov. Potom sa kontroluje, či sa zadané heslo nachádza v prijatom zozname.",
    "Password needs to be at least %s characters long" : "Heslo musí mať aspoň %s znakov",
    "Minimal length" : "Minimálna dĺžka",
    "days until user password expires" : "dní do skončenia platnosti hesla používateľa",
    "login attempts before the user account is blocked. (0 for no limit)" : "pokusy o prihlásenie pred zablokovaním používateľského účtu. (0 bez obmedzenia)"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
